pdf多路召回
https://github.com/PaddlePaddle/PaddleNLP/blob/develop/pipelines/examples/chatbot/chat_pdf_multi_recall_example.py
https://github.com/freedmand/semantra

开源列表
https://github.com/eugeneyan/open-llms

AI智能文章批量生成器
https://ai.de1919.com/
https://blog.csdn.net/weixin_45788869/article/details/130319005?csdn_share_tail=%7B%22type%22%3A%22blog%22%2C%22rType%22%3A%22article%22%2C%22rId%22%3A%22130319005%22%2C%22source%22%3A%22unlogin%22%7D

增加bloom
https://github.com/huggingface/transformers-bloom-inference
https://huggingface.co/bigscience/bloom-560m


提示模板
https://github.com/f/awesome-chatgpt-prompts


https://github.com/TheRamU/Fay


# 赚钱
https://github.com/xiaoming2028/Chatgpt-Makes-Money

#
https://github.com/yuanzhoulvpi2017/zero_nlp

# chatSQL
https://huggingface.co/spaces/ls291/ChatSQL
